@@ -104,11 +104,11 @@ struct file_operations sis1100_fops = {
 #define dev2pci(d) container_of(d, struct pci_dev, dev)
 #define dev2sc(d) pci_get_drvdata(dev2pci(d))
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,13)
-#define SHOW_ARGS(d, a, b) (d, a, b) 
-#define STORE_ARGS(d, a, b, c) (d, a, b, c) 
+#define SHOW_ARGS(d, a, b) (d, a, b)
+#define STORE_ARGS(d, a, b, c) (d, a, b, c)
 #else
-#define SHOW_ARGS(d, a, b) (d, b) 
-#define STORE_ARGS(d, a, b, c) (d, b, c) 
+#define SHOW_ARGS(d, a, b) (d, b)
+#define STORE_ARGS(d, a, b, c) (d, b, c)
 #endif
 
 ssize_t
@@ -171,7 +171,9 @@ static DEVICE_ATTR(remote_ident, 0444, show_remote_ident, 0);
 static DEVICE_ATTR(local_serial, 0444, show_local_serial, 0);
 static DEVICE_ATTR(remote_online, 0444, show_remote_online, 0);
 static DEVICE_ATTR(remote_size, 0444, show_remote_size, 0);
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,13)
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4,13,0)
+static struct class_attribute class_attr_version = __ATTR(version, 0444, show_version, NULL);
+#elif LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,13)
 static CLASS_ATTR(version, 0444, show_version, NULL);
 #endif
 
@@ -224,10 +226,13 @@ init_sis1100_device(struct pci_dev *pdev, const struct pci_device_id *ent)
         sc->testflags=0;
         init_waitqueue_head(&sc->local_wait);
         init_waitqueue_head(&sc->remoteirq_wait);
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4,15,0)
+        timer_setup(&sc->link_up_timer, sis1100_link_up_handler, 0);
+#else
         init_timer(&sc->link_up_timer);
         sc->link_up_timer.function=sis1100_link_up_handler;
         sc->link_up_timer.data=(unsigned long)sc;
-
+#endif
         mutex_init(&sc->sem_hw);
         mutex_init(&sc->sem_fdata);
         mutex_init(&sc->sem_irqinfo);
