@@ -41,6 +41,15 @@
 #include "sis1100_map.h"
 #include "sis1100_var.h"
 
+/*  20APR2018  */
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4,11,0)
+#   include <linux/sched/signal.h>
+#endif
+
+
+/* 16NOV2016 For FEDORA23_Kernel4.2.3.300 */
+#include "linux/vmalloc.h"
+
 #ifndef PCI_VENDOR_FZJZEL
 #   define PCI_VENDOR_FZJZEL 0x1796
 #endif
@@ -268,7 +277,7 @@ int sis1100_read_dma(struct sis1100_softc *sc, struct sis1100_fdata* fd,
         size_t count, size_t* count_read, u_int8_t* data, int* prot_err);
 int _sis1100_read_dma(struct sis1100_softc *sc, struct sis1100_fdata* fd,
         u_int32_t addr, int32_t am, int size, int space, int fifo,
-        size_t count, size_t* count_read, u_int8_t* data, int* prot_err, 
+        size_t count, size_t* count_read, u_int8_t* data, int* prot_err,
         int* may_be_more);
 int sis1100_write_dma(struct sis1100_softc *sc, struct sis1100_fdata* fd,
         u_int32_t addr, int32_t am, int size, int space, int fifo,
